/* --------------------------------------------------------------------------------------------
 * Copyright (c) 2024 TypeFox and others.
 * Licensed under the MIT License. See LICENSE in the package root for license information.
 * ------------------------------------------------------------------------------------------ */
import { useWorkerFactory } from 'monaco-editor-wrapper/workerFactory';
import { RegisteredMemoryFile } from '@codingame/monaco-vscode-files-service-override';
export const disableElement = (id, disabled) => {
    const button = document.getElementById(id);
    if (button !== null) {
        button.disabled = disabled;
    }
};
export const configureMonacoWorkers = (logger) => {
    useWorkerFactory({
        workerLoaders: {
            // if you import monaco api as 'monaco-editor': monaco-editor/esm/vs/editor/editor.worker.js
            TextEditorWorker: () => new Worker(new URL('@codingame/monaco-vscode-editor-api/esm/vs/editor/editor.worker.js', import.meta.url), { type: 'module' }),
            TextMateWorker: () => new Worker(new URL('@codingame/monaco-vscode-textmate-service-override/worker', import.meta.url), { type: 'module' }),
            OutputLinkDetectionWorker: () => new Worker(new URL('@codingame/monaco-vscode-output-service-override/worker', import.meta.url), { type: 'module' }),
            LanguageDetectionWorker: () => new Worker(new URL('@codingame/monaco-vscode-language-detection-worker-service-override/worker', import.meta.url), { type: 'module' }),
            NotebookEditorWorker: () => new Worker(new URL('@codingame/monaco-vscode-notebook-service-override/worker', import.meta.url), { type: 'module' }),
            LocalFileSearchWorker: () => new Worker(new URL('@codingame/monaco-vscode-search-service-override/worker', import.meta.url), { type: 'module' })
        },
        logger
    });
};
export const createDefaultWorkspaceFile = (workspaceFile, workspacePath) => {
    return new RegisteredMemoryFile(workspaceFile, JSON.stringify({
        folders: [
            {
                path: workspacePath
            }
        ]
    }, null, 2));
};
//# sourceMappingURL=utils.js.map